import { ErrorHandler } from '../../models/index.mjs';
import logger from '../logger.mjs';

async function runUseCase(UseCase, { params }) {
    return new UseCase().run(params);
}

export default function makeRequestHandler(UseCase, mapToParams) {
    function logRequest(params, result, startTime) {
        logger.debug({
            useCase: UseCase.name,
            runtime: Date.now() - startTime,
            params,
            result,
        });
    }

    return async function routerHandler(message) {
        try {
            const startTime = Date.now();
            const params = mapToParams(message);

            const result = await runUseCase(UseCase, { params });

            logRequest(params, result, startTime);
        } catch (err) {
            ErrorHandler.handleRequestError(err);
        }
    };
}
