import Position from './position.mjs';
import Data from './data.mjs';
import Event from './event.mjs';

import Obsolete from './obsolete.mjs';
import { ZMQ_SUB_CHANNELS } from '../../../system/constants.mjs';
import logger from '../../logger.mjs';
import { getChannelWithMessage } from '../../../utils/index.mjs';

export default async function (zmqBuffer) {
    const rawMessage = zmqBuffer.toString();
    const { channel, message } = getChannelWithMessage(rawMessage);

    switch (channel) {
        case ZMQ_SUB_CHANNELS.POS: {
            await Position.post(message);
            return null;
        }
        case ZMQ_SUB_CHANNELS.DATA: {
            await Data.post(message);
            return null;
        }
        case ZMQ_SUB_CHANNELS.EVENT: {
            await Event.post(message);
            return null;
        }
        case ZMQ_SUB_CHANNELS.OBSOLETE: {
            await Obsolete.post(message);
            return null;
        }
    }

    logger.debug('No handler for channel %s', channel);
}
