import UseCaseBase from '../UseCaseBase.mjs';
import { Position, NodeAssociation, Sublocation, Device } from '../../models/index.mjs';
import { formatPosition } from './formatters.mjs';

export class PositionSave extends UseCaseBase {
    /**
     * @method
     * @param {Object} params  - raw position form JSON/BIN convertor
     * @property {String} params.ts  - position timestamp in ISO 8601 format
     * @property {String} params.mac  - hardware device MAC address
     * @property {Object} params.data  - position properties
     * @property {Number} params.data.x  - the X coordinate of the position
     * @property {Number} params.data.y  - the Y coordinate of the position
     * @property {Number} params.data.z  - the Z coordinate of the position
     * @property {Number} params.data.sl_id  - sublocation numeric identifier
     * @property {Number} params.data.fom  - the figure of merit
     * @property {String} params.data.slvr_mode  - the PE solver mode (NONE, PD, 0D, 1D, TDOA, TWOA, UNKNOWN)
     * @property {Boolean} params.data.inactive  - the flag that indicated the tag mode: false - tag is moving, true - tag is not moving
     * @returns {Promise<null>}
     */
    async execute(params) {
        const association = await new NodeAssociation().findByMac(params);
        const sublocationUid = await new Sublocation().findUidById(params.data);
        const trackableUid = association ? association.trackable_uid : null;
        const position = formatPosition(params, trackableUid, sublocationUid, 'UWB');
        if (position.tk_uid) {
            await this.notificator.notify(Position.notifyMessage(position));
            await new Position().save(position);
        }
        await new Device().updateLastHeard(params.mac, params.ts);

        return null;
    }
}
