import { ZMQ_ACTIONS, ZMQ_CHANNELS } from '../system/constants.mjs';

export default class ModelBase {
    /**
     * @typedef {Class} ModelBase
     */

    /**
     * @property {String|null}
     */
    static object = null;

    /**
     * @type {Repository}
     */
    repository = null;

    constructor() {
        this.repository = ModelBase.repositoryInstance;
    }

    /**
     * @method
     * @param {Object} data - anchor object
     * @return {Object}
     */
    static savedMessage(data) {
        return {
            action: ZMQ_ACTIONS.CREATED,
            object: this.object,
            channel: ZMQ_CHANNELS.EVENT,
            data,
        };
    }
    /**
     * @method
     * @param {Object} data - anchor object
     * @return {Object}
     */
    static updatedMessage(data) {
        return {
            action: ZMQ_ACTIONS.UPDATED,
            object: this.object,
            channel: ZMQ_CHANNELS.EVENT,
            data,
        };
    }
    /**
     * @method
     * @param {Object} data - anchor object
     * @return {Object}
     */
    static deletedMessage(data) {
        return {
            action: ZMQ_ACTIONS.DELETED,
            object: this.object,
            channel: ZMQ_CHANNELS.EVENT,
            data,
        };
    }

    /**
     * @static
     * @return {Repository}
     */
    static repositoryInstance = null;

    /**
     * @static
     * @method
     */
    static setRepository(repository) {
        ModelBase.repositoryInstance = repository;
    }

    /**
     * @method
     * @param {Object} data - save data
     * @return {Promise<Object>}
     */
    async save(data) {
        return { data };
    }

    /**
     * @method
     * @param {Object} params - load options
     * @return {Promise<Object>}
     */
    // eslint-disable-next-line no-unused-vars
    async load(params) {
        return {};
    }

    /**
     * @method
     * @param {Object} params - parameters for entity remove
     * @return {Promise<Object>}
     */
    async remove(params) {
        return { params };
    }

    /**
     * @method
     * @param {Object} data - updated entity
     * @return {Promise<Object>}
     */
    async update(data) {
        return { data };
    }
}
