import LIVR from 'livr';
import extraRules from 'livr-extra-rules';
import * as extraRulesCustom from '../system/livr-extra-rules/index.mjs';
import { ValidationError } from '../models/index.mjs';

export default class UseCaseBase {
    constructor() {
        this.validator = null;

        this.notificator = UseCaseBase.notificatorInstance;
    }

    static notificatorInstance = {
        notify: () => {
            if (process.env.MODE === 'test') return;
            throw new Error('notificator is not set');
        },
    };

    static setNotificator(notificator) {
        UseCaseBase.notificatorInstance = notificator;
    }

    async run(params) {
        const cleanParams = await this.validate(params);
        if (cleanParams) {
            return this.execute(cleanParams);
        }
        const errors = this.validator.getErrors();
        throw new ValidationError(JSON.stringify(errors));
    }

    async validate(params) {
        this.validator = new LIVR.Validator(this.constructor.validationRules);
        // console.log('extraRulesCustom', { ...extraRulesCustom });
        this.validator.registerRules({ ...extraRules, ...extraRulesCustom });

        return this.validator.validate(params);
    }
}
