import UseCaseBase from '../UseCaseBase.mjs';
import { Anchor, Location, NodeAssociation, Sublocation, NetworkLsbSchedule, NetworkSetting } from '../../models/index.mjs';

export class LocationDelete extends UseCaseBase {
    static validationRules = {
        uid: ['strict_string', 'required'],
    };

    async execute(params) {
        const {
            sublocations,
            anchors,
            nodeAssociations,
            networkLsbSchedules,
            networkSetting,
        } = await new Location().loadWithChildren(params);

        for (const nodeAssociation of nodeAssociations) {
            await new NodeAssociation().close(nodeAssociation);
            await this.notificator.notify(NodeAssociation.deletedMessage(nodeAssociation));
        }

        for (const anchor of anchors) {
            await new Anchor().remove(anchor);
            await this.notificator.notify(Anchor.deletedMessage({ uid: anchor.uid }));
        }

        for (const sublocation of sublocations) {
            await new Sublocation().remove(sublocation);
            await this.notificator.notify(Sublocation.deletedMessage({ uid: sublocation.uid }));
        }

        for (const networkLsbSchedule of networkLsbSchedules) {
            await new NetworkLsbSchedule().remove(networkLsbSchedule);
            await this.notificator.notify(NetworkLsbSchedule.deletedMessage({ uid: networkLsbSchedule.uid }));
        }

        if (networkSetting) {
            await new NetworkSetting().remove({ location_uid: params.uid });
            await this.notificator.notify(NetworkSetting.deletedMessage(params));
        }

        await new Location().remove(params);
        await this.notificator.notify(Location.deletedMessage(params));

        return params;
    }
}
