import RepoBase from '../RepoBase.mjs';

/**
 * @typedef SolutionTrackable {Object}
 * @property name {String}
 * @property uid {String}
 * @property default_height {Number}
 * @property to_type_id {Number}
 * @property created_at {Date}
 * @property updated_at {Date}
 * @property position {Object}
 * @property pos_report_frequency {Number}
 * @property stationary {Number}
 */
/**
 * @class TrackableRepository
 * @description create access for the trackables in the solutions DB
 */
export class TrackableRepository extends RepoBase {
    /**
     * @param {Object} options - repository options
     * @param {Object} options.repositoryInstance - database connection
     */
    constructor(options) {
        const { repositoryInstance } = options;
        super(repositoryInstance);
    }

    /**
     * @method
     * @return {Promise<SolutionTrackable[]>} returns result of search by key
     */
    async readAll() {
        return (await this.repoInstance.queryAsync(TrackableRepository.readAllSql) || []);
    }
    
    static get readAllSql() {
        return `select
                    name, uid, default_height, to_type_id, created_at, updated_at, position, pos_report_frequency, stationary
                from view_trackable_objects
                where removed_at > NOW();`
    }
}
